%define abi     0.9
%define libname %mklibname %{name} %{abi}

Name:           mgba
Version:        0.9.1
Release:        %mkrel 1
Summary:        Fast and accurate Game Boy Advance emulator
Group:          Emulators
License:        MPLv2.0
URL:            https://mgba.io
Source0:        https://github.com/mgba-emu/mgba/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  ffmpeg-devel
BuildRequires:  lzma-devel
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(libedit)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(MagickWand)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sqlite3)

Recommends:     %{name}-qt

%description
mGBA is an emulator for running Game Boy Advance games. It aims to be
faster and more accurate than many existing Game Boy Advance emulators,
as well as adding features that other emulators lack. It also supports
Game Boy and Game Boy Color games.

This package contains the command-line SDL 2 frontend for mGBA; the
"%{name}-qt" package contains a full-featured graphical Qt 5 frontend.

%package qt
Summary:        Qt 5 frontend for the mGBA emulator

# This used to have the data folder, but it's used by qt.
# A data folder in a libified packaged triggers upgrade conflicts.
Obsoletes:      %{_lib}mgba0.6 < 0.8.3-1

%description qt
This package contains the Qt 5 frontend of the mGBA emulator. The
lighter weight command-line SDL 2 frontend is provided by the "%{name}"
package.

%package -n %{libname}
Summary:        Shared data and library used by mGBA's Qt and SDL frontends
Group:          System/Libraries

%description -n %{libname}
This package contains the mGBA library and data files used by both the
Qt and SDL frontends of the mGBA emulator.

%prep
%autosetup -p1

# Unbundle thirdparty libs
rm -rf src/third-party/{libpng,sqlite3,zlib}

# Fixup missed version bump in 0.8.4
sed -i version.cmake -e "s/LIB_VERSION_PATCH 3/LIB_VERSION_PATCH 4/"

%build
%cmake
%cmake_build

%install
%cmake_install

# We don't package the devel lib for now.
rm -rf %{buildroot}%{_libdir}/lib%{name}.so
rm -rf %{buildroot}%{_includedir}
rm -rf %{buildroot}%{_docdir}/mGBA

%files
%doc CHANGES README.md
%license LICENSE
%{_bindir}/%{name}
%{_mandir}/man6/%{name}.6*

%files qt
%doc CHANGES README.md
%license LICENSE
%{_bindir}/%{name}-qt
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}-qt.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_mandir}/man6/%{name}-qt.6*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{abi}
%{_libdir}/lib%{name}.so.%{version}


%changelog
* Wed Jun 02 2021 akien <akien> 0.9.1-1.mga8
+ Revision: 1729399
- Version 0.9.1
+ neoclust <neoclust>
- Rebuild against new imagemagick

* Sun Jan 17 2021 akien <akien> 0.8.4-1.mga8
+ Revision: 1672252
- Version 0.8.4

* Thu Dec 17 2020 umeabot <umeabot> 0.8.3-3.mga8
+ Revision: 1659057
- Rebuild for new Qt5

* Wed Oct 21 2020 akien <akien> 0.8.3-2.mga8
+ Revision: 1637810
- Fix packaging of Qt-specific data dir, add obsoletes to ease upgrade

* Wed Oct 21 2020 akien <akien> 0.8.3-1.mga8
+ Revision: 1637667
- Version 0.8.3

* Tue Feb 18 2020 umeabot <umeabot> 0.6.3-7.mga8
+ Revision: 1541587
- Mageia 8 Mass Rebuild

* Mon Dec 30 2019 kekepower <kekepower> 0.6.3-6.mga8
+ Revision: 1474981
- Use new cmake macros
- Rebuild for new imagemagick

* Sun Mar 31 2019 umeabot <umeabot> 0.6.3-5.mga7
+ Revision: 1383378
- Qt5 Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 0.6.3-4.mga7
+ Revision: 1299529
- Mageia 7 Mass Rebuild

* Sat Jun 02 2018 daviddavid <daviddavid> 0.6.3-3.mga7
+ Revision: 1233603
- add patch to fix build with new Qt5 >= 5.11.0 stack

* Wed May 02 2018 kekepower <kekepower> 0.6.3-2.mga7
+ Revision: 1224489
- Rebuild for ImageMagic 7.0.7.29

* Sun Apr 29 2018 daviddavid <daviddavid> 0.6.3-1.mga7
+ Revision: 1223591
- new version: 0.6.3

* Thu Jan 18 2018 shlomif <shlomif> 0.6.0-3.mga7
+ Revision: 1194417
- Rebuild for new imagemagick

* Sat Dec 30 2017 wally <wally> 0.6.0-2.mga7
+ Revision: 1187971
- rebuild for new libzip

* Sun Jul 23 2017 akien <akien> 0.6.0-1.mga7
+ Revision: 1129655
- imported package mgba

